@@ -201,8 +201,13 @@ class Hatchet(object):
         try:
             self.logger.debug("building PySide in %r",builddir)
             if os.path.exists(os.path.join(builddir,BUILD_OK_MARKER)):
-                nm = os.listdir(builddir)[0]
-                sourcedir = os.path.join(builddir,nm)
+                for nm in os.listdir(builddir):
+                    if nm != BUILD_OK_MARKER:
+                       sourcedir = os.path.join(builddir,nm)
+                       break
+                else:
+                    msg = "Broken cached builddir: %s" % (builddir,)
+                    raise RuntimeError(msg)
                 self.logger.debug("using cached builddir: %r",sourcedir)
             else:
                 sourcefile = self.fetch_pyside_source()
@@ -844,9 +849,6 @@ class Hatchet(object):
         if "linux" in sys.platform:
             ldflags = env.get("LDFLAGS",os.environ.get("LDFLAGS",""))
             ldflags += " " + sysconfig.get_config_var("LDFLAGS")
-            #  These are required for static linking on linux
-            ldflags += " -lpthread -lrt -lz -ldl -lQtNetwork -lQtCore -ljpeg -ltiff -lpng14 -lz -lX11 -lXrender -lXrandr -lXext -lfontconfig -lSM -lICE"
-            ldflags += " --gc-sections"
             env["LDFLAGS"] = ldflags
         return env
 
